#!/bin/sh

# File Name: SampleScript.sh
# Author: Benoit Valin (bvalin@tsinghua.edu.cn)
# Date: 15th of december 2003
# Description: Pilot script for the rSVM 2.0 package. Data and results 
#              are meaning less, the commands are just to illustrate 
#              the functionalities of the programs. 


#----preprocessor----
echo 
echo "preprocessor"

# preprocess the data
preprocessor demodata_ch2.xls CH2 SampleScriptData.xls -idx2 Class_a.idx Class_b.idx -topcut 200 
preprocessor SampleScriptData.xls RSVM2 SampleScriptData.xls -geneexc M9
preprocessor SampleScriptData.xls RSVM2 SampleScriptData.xls -idx1 SampleScriptData.xls.idx -smplexc A4
preprocessor SampleScriptData.xls RSVM2 SampleScriptData.xls -idx1 SampleScriptData.xls.idx -smplthresh -5000 30500
preprocessor SampleScriptData.xls RSVM2 SampleScriptData.xls -std 0 1 -topsel 1500
#-------DONE---------




#-------rSVM---------
echo 
echo "rSVM"

# (for demo purpose) creation of the Gene selection counter file
echo "1500" > UserSelection.txt
echo "700" >> UserSelection.txt
echo "600" >> UserSelection.txt
echo "500" >> UserSelection.txt
echo "400" >> UserSelection.txt
echo "300" >> UserSelection.txt
echo "200" >> UserSelection.txt
echo "100" >> UserSelection.txt
echo "50" >> UserSelection.txt
echo "25" >> UserSelection.txt
echo "10" >> UserSelection.txt
echo "5" >> UserSelection.txt

# creating the models
rSVM SampleScriptData.xls SampleScriptData.xls.idx -user UserSelection.txt
#-------DONE---------




#----crossSVM--------
echo 
echo "crossSVM"

# executing leave one out cross validation test
crossSVM SampleScriptData.xls SampleScriptData.xls.idx CV_stats.txt -user UserSelection.txt
#-------DONE---------





#----permuteSVM------
echo 
echo "permuteSVM"

# executing permutation (leave one out cross validation) tests
permuteSVM SampleScriptData.xls SampleScriptData.xls.idx Permutation_stats.txt 3 -user UserSelection.txt -seed 54321

# (for demo purpose) deletion of the Gene selection counter file
rm -f UserSelection.txt
#-------DONE---------





#----predictSVM------
echo 
echo "predictSVM"

# preprocessing a new data set to do predictions
preprocessor SampleScriptData.xls RSVM2 SampleScriptDataPredict.xls -genes 5g.genes

# predicting class based on a created model
predictSVM 5g.model SampleScriptDataPredict.xls Predict_stats.txt
#-------DONE---------

echo 
echo "DONE ! ! !"
